##  Finding Your S-User Administrator
Only S-user administrators can create and manage S-user IDs. If you aren't an administrator, work with your S-user administrator to get started.
If you're new to SAP or don't know who your administrator is, try the following:
  * Review your welcome email from SAP. It often includes your initial S-user ID and contact information for your administrator.
  * Ask your internal IT team or SAP contact. Most organizations have a designated SAP administrator.
  * Contact SAP Support through the [SAP Support Portal![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fsupport.sap.com%2Fen%2Findex.html?locale=en-US&state=PRODUCTION&version=CLOUD "https://support.sap.com/en/index.html") to identify your administrator.
